@@ -39,6 +39,10 @@
 #'  the data are converted to the required format. In this case, any
 #'  calls in the resulting model objects reference the temporary
 #'  objects used to fit the model.
+#'
+#' If the model engine has not been set, the model's default engine will be used
+#'  (as discussed on each model page). If the `verbosity` option of
+#'  [fit_control()] is greater than zero, a warning will be produced.
 #' @examples
 #' # Although `glm()` only has a formula interface, different
 #' # methods for specifying the model can be used
@@ -48,8 +52,6 @@
 #'
 #' lr_mod <- logistic_reg()
 #'
-#' lr_mod <- logistic_reg()
-#'
 #' using_formula <-
 #'   lr_mod %>%
 #'   set_engine("glm") %>%
@@ -93,8 +95,13 @@ fit.model_spec <-
            ...
   ) {
     dots <- quos(...)
-    if (any(names(dots) == "engine"))
-      stop("Use `set_engine()` to supply the engine.", call. = FALSE)
+    if (is.null(object$engine)) {
+      eng_vals <- possible_engines(object)
+      object$engine <- eng_vals[1]
+      if (control$verbosity > 0) {
+        warning("Engine set to `", object$engine, "`", call. = FALSE)
+      }
+    }
 
     if (all(c("x", "y") %in% names(dots)))
       stop("`fit.model_spec()` is for the formula methods. Use `fit_xy()` instead.",
@@ -116,7 +123,7 @@ fit.model_spec <-
       )
 
     # populate `method` with the details for this model type
-    object <- get_method(object, engine = object$engine)
+    object <- add_methods(object, engine = object$engine)
 
     check_installs(object)
 
@@ -177,8 +184,13 @@ fit_xy.model_spec <-
            ...
   ) {
     dots <- quos(...)
-    if (any(names(dots) == "engine"))
-      stop("Use `set_engine()` to supply the engine.", call. = FALSE)
+    if (is.null(object$engine)) {
+      eng_vals <- possible_engines(object)
+      object$engine <- eng_vals[1]
+      if (control$verbosity > 0) {
+        warning("Engine set to `", object$engine, "`", call. = FALSE)
+      }
+    }
 
     if (object$engine != "spark" & NCOL(y) == 1 & !(is.vector(y) | is.factor(y))) {
       if (is.matrix(y)) {
@@ -201,7 +213,7 @@ fit_xy.model_spec <-
       )
 
     # populate `method` with the details for this model type
-    object <- get_method(object, engine = object$engine)
+    object <- add_methods(object, engine = object$engine)
 
     check_installs(object)
 
@@ -225,7 +237,7 @@ fit_xy.model_spec <-
             ...
           ),
 
-        data.frame_data.frame =, matrix_data.frame =
+        data.frame_data.frame = , matrix_data.frame =
           xy_xy(
             object = object,
             env = eval_env,
@@ -235,7 +247,7 @@ fit_xy.model_spec <-
           ),
 
         # heterogenous combinations
-        matrix_formula =,  data.frame_formula =
+        matrix_formula = ,  data.frame_formula =
           xy_form(
             object = object,
             env = eval_env,
@@ -353,7 +365,7 @@ check_xy_interface <- function(x, y, cl, model) {
 print.model_fit <- function(x, ...) {
   cat("parsnip model object\n\n")
 
-  if(inherits(x$fit, "try-error")) {
+  if (inherits(x$fit, "try-error")) {
     cat("Model fit failed with error:\n", x$fit, "\n")
   } else {
     print(x$fit, ...)
