@@ -132,14 +132,6 @@ make_call <- function(fun, ns, args, ...) {
   out
 }
 
-resolve_args <- function(args, ...) {
-  for (i in seq(along = args)) {
-    if (!is_missing_arg(args[[i]]))
-      args[[i]] <- eval_tidy(args[[i]], ...)
-  }
-  args
-}
-
 levels_from_formula <- function(f, dat) {
   if (inherits(dat, "tbl_spark"))
     res <- NULL
@@ -152,8 +144,8 @@ is_spark <- function(x)
   isTRUE(unname(x$method$fit$func["pkg"] == "sparklyr"))
 
 
-show_fit <- function(mod, eng) {
-  mod <- translate(x = mod, engine = eng)
+show_fit <- function(model, eng) {
+  mod <- translate(x = model, engine = eng)
   fit_call <- show_call(mod)
   call_text <-  deparse(fit_call)
   call_text <- paste0(call_text, collapse = "\n")
@@ -201,7 +193,7 @@ update_dot_check <- function(...) {
 # ------------------------------------------------------------------------------
 
 new_model_spec <- function(cls, args, eng_args, mode, method, engine) {
-  spec_modes <- get(paste0(cls, "_modes"))
+  spec_modes <- rlang::env_get(get_model_env(), paste0(cls, "_modes"))
   if (!(mode %in% spec_modes))
     stop("`mode` should be one of: ",
          paste0("'", spec_modes, "'", collapse = ", "),
@@ -231,3 +223,15 @@ check_outcome <- function(y, spec) {
   invisible(NULL)
 }
 
+
+# Get's a character string of varible names used as the outcome
+# in a terms object
+terms_y <- function(x) {
+  att <- attributes(x)
+  resp_ind <- att$response
+  y_expr <- att$predvars[[resp_ind + 1]]
+  all.vars(y_expr)
+}
+
+
+
