@@ -34,7 +34,7 @@
 #' The model can be created using the `fit()` function using the
 #'  following _engines_:
 #' \itemize{
-#' \item \pkg{R}:   `"glmnet"`
+#' \item \pkg{R}:   `"glmnet"`  (the default)
 #' \item \pkg{Stan}:  `"stan"`
 #' \item \pkg{keras}: `"keras"`
 #' }
@@ -57,9 +57,9 @@
 #'
 #' \Sexpr[results=rd]{parsnip:::show_fit(parsnip:::multinom_reg(), "keras")}
 #'
-#' When using `glmnet` models, there is the option to pass
-#'  multiple values (or no values) to the `penalty` argument. This
-#'  can have an effect on the model object results. When using the
+#' For `glmnet` models, the full regularization path is always fit regardless
+#' of the value given to `penalty`. Also, there is the option to pass
+#'  multiple values (or no values) to the `penalty` argument. When using the
 #'  `predict()` method in these cases, the return value depends on
 #'  the value of `penalty`. When using `predict()`, only a single
 #'  value of the penalty can be used. When predicting on multiple
@@ -112,7 +112,7 @@ print.multinom_reg <- function(x, ...) {
   cat("Multinomial Regression Model Specification (", x$mode, ")\n\n", sep = "")
   model_printer(x, ...)
 
-  if(!is.null(x$method$fit$args)) {
+  if (!is.null(x$method$fit$args)) {
     cat("Model fit template:\n")
     print(show_call(x))
   }
@@ -120,6 +120,9 @@ print.multinom_reg <- function(x, ...) {
   invisible(x)
 }
 
+#' @export
+translate.multinom_reg <- translate.linear_reg
+
 # ------------------------------------------------------------------------------
 
 #' @inheritParams update.boost_tree
@@ -188,7 +191,7 @@ organize_multnet_prob <- function(x, object) {
 }
 
 # ------------------------------------------------------------------------------
-# glmnet call stack for linear regression using `predict` when object has
+# glmnet call stack for multinomial regression using `predict` when object has
 # classes "_multnet" and "model_fit" (for class predictions):
 #
 #  predict()
@@ -199,7 +202,7 @@ organize_multnet_prob <- function(x, object) {
 #       predict.multnet()
 
 
-# glmnet call stack for linear regression using `multi_predict` when object has
+# glmnet call stack for multinomial regression using `multi_predict` when object has
 # classes "_multnet" and "model_fit" (for class predictions):
 #
 # 	multi_predict()
@@ -217,6 +220,11 @@ organize_multnet_prob <- function(x, object) {
 predict._multnet <-
   function(object, new_data, type = NULL, opts = list(), penalty = NULL, multi = FALSE, ...) {
 
+    # See discussion in https://github.com/tidymodels/parsnip/issues/195
+    if (is.null(penalty) & !is.null(object$spec$args$penalty)) {
+      penalty <- object$spec$args$penalty
+    }
+
     object$spec$args$penalty <- check_penalty(penalty, object, multi)
 
     object$spec <- eval_args(object$spec)
@@ -232,6 +240,7 @@ predict._multnet <-
 #' @importFrom dplyr full_join as_tibble arrange
 #' @importFrom tidyr gather
 #' @export
+#' @rdname multi_predict
 multi_predict._multnet <-
   function(object, new_data, type = NULL, penalty = NULL, ...) {
     if (any(names(enquos(...)) == "newdata"))
@@ -241,14 +250,20 @@ multi_predict._multnet <-
       penalty <- eval_tidy(penalty)
 
     dots <- list(...)
-    if (is.null(penalty))
-      penalty <- eval_tidy(object$fit$lambda)
+    if (is.null(penalty)) {
+      # See discussion in https://github.com/tidymodels/parsnip/issues/195
+      if (!is.null(object$spec$args$penalty)) {
+        penalty <- object$spec$args$penalty
+      } else {
+        penalty <- object$fit$lambda
+      }
+    }
     dots$s <- penalty
 
     if (is.null(type))
       type <- "class"
     if (!(type %in% c("class", "prob", "link", "raw"))) {
-      stop ("`type` should be either 'class', 'link', 'raw', or 'prob'.", call. = FALSE)
+      stop("`type` should be either 'class', 'link', 'raw', or 'prob'.", call. = FALSE)
     }
     if (type == "prob")
       dots$type <- "response"
@@ -289,19 +304,19 @@ multi_predict._multnet <-
   }
 
 #' @export
-predict_class._multnet <- function (object, new_data, ...) {
+predict_class._multnet <- function(object, new_data, ...) {
   object$spec <- eval_args(object$spec)
   predict_class.model_fit(object, new_data = new_data, ...)
 }
 
 #' @export
-predict_classprob._multnet <- function (object, new_data, ...) {
+predict_classprob._multnet <- function(object, new_data, ...) {
   object$spec <- eval_args(object$spec)
   predict_classprob.model_fit(object, new_data = new_data, ...)
 }
 
 #' @export
-predict_raw._multnet <- function (object, new_data, opts = list(), ...) {
+predict_raw._multnet <- function(object, new_data, opts = list(), ...) {
   object$spec <- eval_args(object$spec)
   predict_raw.model_fit(object, new_data = new_data, opts = opts, ...)
 }
@@ -322,7 +337,10 @@ check_glmnet_lambda <- function(dat, object) {
   dat
 }
 
+
 # ------------------------------------------------------------------------------
 
-#' @importFrom utils globalVariables
-utils::globalVariables(c("group", ".pred"))
+#' @export
+#' @export min_grid.multinom_reg
+#' @rdname min_grid
+min_grid.multinom_reg <- min_grid.linear_reg
