@@ -29,7 +29,8 @@
 #' `"classification"`.
 #'
 #' @param neighbors A single integer for the number of neighbors
-#' to consider (often called `k`).
+#' to consider (often called `k`). For \pkg{kknn}, a value of 5
+#' is used if `neighbors` is not specified.
 #'
 #' @param weight_func A *single* character for the type of kernel function used
 #' to weight distances between samples. Valid choices are: `"rectangular"`,
@@ -43,7 +44,7 @@
 #' The model can be created using the `fit()` function using the
 #'  following _engines_:
 #' \itemize{
-#' \item \pkg{R}:  `"kknn"`
+#' \item \pkg{R}:  `"kknn"`  (the default)
 #' }
 #'
 #' @section Engine Details:
@@ -54,7 +55,7 @@
 #'
 #' \pkg{kknn} (classification or regression)
 #'
-#' \Sexpr[results=rd]{parsnip:::show_fit(parsnip:::nearest_neighbor(), "kknn")}
+#' \Sexpr[results=rd]{parsnip:::show_fit(parsnip:::nearest_neighbor(mode = "regression"), "kknn")}
 #'
 #' @note
 #' For `kknn`, the underlying modeling function used is a restricted
@@ -148,13 +149,107 @@ check_args.nearest_neighbor <- function(object) {
 
   args <- lapply(object$args, rlang::eval_tidy)
 
-  if(is.numeric(args$neighbors) && !positive_int_scalar(args$neighbors)) {
+  if (is.numeric(args$neighbors) && !positive_int_scalar(args$neighbors)) {
     stop("`neighbors` must be a length 1 positive integer.", call. = FALSE)
   }
 
-  if(is.character(args$weight_func) && length(args$weight_func) > 1) {
+  if (is.character(args$weight_func) && length(args$weight_func) > 1) {
     stop("The length of `weight_func` must be 1.", call. = FALSE)
   }
 
   invisible(object)
 }
+
+# ------------------------------------------------------------------------------
+
+#' @export
+translate.nearest_neighbor <- function(x, engine = x$engine, ...) {
+  if (is.null(engine)) {
+    message("Used `engine = 'kknn'` for translation.")
+    engine <- "kknn"
+  }
+  x <- translate.default(x, engine, ...)
+
+  if (engine == "kknn") {
+    if (!any(names(x$method$fit$args) == "ks") ||
+        is_missing_arg(x$method$fit$args$ks)) {
+      x$method$fit$args$ks <- 5
+    }
+  }
+  x
+}
+
+
+# ------------------------------------------------------------------------------
+
+#' @importFrom purrr map_df
+#' @importFrom dplyr starts_with
+#' @rdname multi_predict
+#' @param neighbors An integer vector for the number of nearest neighbors.
+#' @export
+multi_predict._train.kknn <-
+  function(object, new_data, type = NULL, neighbors = NULL, ...) {
+    if (any(names(enquos(...)) == "newdata"))
+      stop("Did you mean to use `new_data` instead of `newdata`?", call. = FALSE)
+
+    if (is.null(neighbors))
+      neighbors <- rlang::eval_tidy(object$fit$call$ks)
+    neighbors <- sort(neighbors)
+
+    if (is.null(type)) {
+      if (object$spec$mode == "classification")
+        type <- "class"
+      else
+        type <- "numeric"
+    }
+
+    res <-
+      purrr::map_df(neighbors, knn_by_k, object = object,
+                    new_data = new_data, type = type, ...)
+    res <- dplyr::arrange(res, .row, neighbors)
+    res <- split(res[, -1], res$.row)
+    names(res) <- NULL
+    dplyr::tibble(.pred = res)
+  }
+
+knn_by_k <- function(k, object, new_data, type, ...) {
+  object$fit$best.parameters$k <- k
+
+  predict(object, new_data = new_data, type = type, ...) %>%
+    dplyr::mutate(neighbors = k, .row = dplyr::row_number()) %>%
+    dplyr::select(.row, neighbors, dplyr::starts_with(".pred"))
+}
+
+# ------------------------------------------------------------------------------
+
+#' @export
+#' @export min_grid.nearest_neighbor
+#' @rdname min_grid
+min_grid.nearest_neighbor <- function(x, grid, ...) {
+
+  grid_names <- names(grid)
+  param_info <- get_submodel_info(x, grid)
+
+  if (!any(param_info$has_submodel)) {
+    return(blank_submodels(grid))
+  }
+
+  fixed_args <- get_fixed_args(param_info)
+
+  fit_only <-
+    grid %>%
+    dplyr::group_by(!!!rlang::syms(fixed_args)) %>%
+    dplyr::summarize(neighbors = max(neighbors, na.rm = TRUE)) %>%
+    dplyr::ungroup()
+
+  min_grid_df <-
+    dplyr::full_join(fit_only %>% rename(max_neighbor = neighbors), grid, by = fixed_args) %>%
+    dplyr::filter(neighbors != max_neighbor) %>%
+    dplyr::rename(sub_neighbors = neighbors, neighbors = max_neighbor) %>%
+    dplyr::group_by(!!!rlang::syms(fixed_args)) %>%
+    dplyr::summarize(.submodels = list(list(neighbors = sub_neighbors))) %>%
+    dplyr::ungroup() %>%
+    dplyr::full_join(fit_only, grid, by = fixed_args)
+
+  min_grid_df  %>% dplyr::select(dplyr::one_of(grid_names), .submodels)
+}
