@@ -25,7 +25,7 @@ test_that('glmnet execution', {
   skip_if_not_installed("glmnet")
 
   expect_error(
-    fit_xy(
+    res <- fit_xy(
       iris_basic,
       control = ctrl,
       x = iris[, num_pred],
@@ -34,6 +34,9 @@ test_that('glmnet execution', {
     regexp = NA
   )
 
+  expect_true(has_multi_predict(res))
+  expect_equal(multi_predict_args(res), "penalty")
+
   expect_error(
     fit(
       iris_basic,
@@ -64,10 +67,10 @@ test_that('glmnet prediction, single lambda', {
     y = iris$Sepal.Length
   )
 
-  uni_pred <- c(5.05124049139868, 4.87103404621362, 4.91028250633598, 4.9399094532023,
-                5.08728178043569)
+  uni_pred <- c(5.05125589060219, 4.86977761622526, 4.90912345599309, 4.93931874108359,
+                5.08755154547758)
 
-  expect_equal(uni_pred, predict(res_xy, iris[1:5, num_pred])$.pred)
+  expect_equal(uni_pred, predict(res_xy, iris[1:5, num_pred])$.pred, tolerance = 0.0001)
 
   res_form <- fit(
     iris_basic,
@@ -76,10 +79,10 @@ test_that('glmnet prediction, single lambda', {
     control = ctrl
   )
 
-  form_pred <- c(5.24228948237804, 5.09448280355765, 5.15636527125752, 5.12592317615935,
-                 5.26930099973607)
+  form_pred <- c(5.23960117346944, 5.08769210344022, 5.15129212608077, 5.12000510716518,
+                 5.26736239856889)
 
-  expect_equal(form_pred, predict(res_form, iris[1:5,])$.pred)
+  expect_equal(form_pred, predict(res_form, iris[1:5,])$.pred, tolerance = 0.0001)
 })
 
 
@@ -129,7 +132,8 @@ test_that('glmnet prediction, multiple lambda', {
     as.data.frame(mult_pred),
     multi_predict(res_xy, new_data = iris[1:5, num_pred], lambda = lams) %>%
       unnest() %>%
-      as.data.frame()
+      as.data.frame(),
+    tolerance = 0.0001
   )
 
   res_form <- fit(
@@ -173,7 +177,8 @@ test_that('glmnet prediction, multiple lambda', {
     as.data.frame(form_pred),
     multi_predict(res_form, new_data = iris[1:5, ], lambda = lams) %>%
       unnest() %>%
-      as.data.frame()
+      as.data.frame(),
+    tolerance = 0.0001
   )
 })
 
@@ -246,7 +251,7 @@ test_that('submodel prediction', {
   )
 
   reg_fit <-
-    linear_reg(penalty = c(0, 0.01, 0.1)) %>%
+    linear_reg() %>%
     set_engine("glmnet") %>%
     fit(mpg ~ ., data = mtcars[-(1:4), ])
 
@@ -271,12 +276,6 @@ test_that('error traps', {
 
   skip_if_not_installed("glmnet")
 
-  expect_error(
-    linear_reg(penalty = .1) %>%
-      set_engine("glmnet") %>%
-      fit(mpg ~ ., data = mtcars[-(1:4), ]) %>%
-      predict(mtcars[-(1:4), ], penalty = .2)
-  )
   expect_error(
     linear_reg() %>%
       set_engine("glmnet") %>%
@@ -292,3 +291,36 @@ test_that('error traps', {
 
 })
 
+
+test_that('glmnet grid reduction', {
+  reg_grid <- expand.grid(penalty = 1:3, mixture = (1:5)/5)
+  reg_grid_smol <- min_grid(linear_reg() %>% set_engine("glmnet"), reg_grid)
+
+  expect_equal(reg_grid_smol$penalty, rep(3, 5))
+  expect_equal(reg_grid_smol$mixture, (1:5)/5)
+  for (i in 1:nrow(reg_grid_smol)) {
+    expect_equal(reg_grid_smol$.submodels[[i]], list(penalty = 1:2))
+  }
+
+  reg_ish_grid <- expand.grid(penalty = 1:3, mixture = (1:5)/5)[-3,]
+  reg_ish_grid_smol <- min_grid(linear_reg() %>% set_engine("glmnet"), reg_ish_grid)
+
+  expect_equal(reg_ish_grid_smol$penalty, c(2, rep(3, 4)))
+  expect_equal(reg_ish_grid_smol$mixture, (1:5)/5)
+  expect_equal(reg_ish_grid_smol$.submodels[[1]], list(penalty = 1))
+  for (i in 2:nrow(reg_ish_grid_smol)) {
+    expect_equal(reg_ish_grid_smol$.submodels[[i]], list(penalty = 1:2))
+  }
+
+  reg_grid_extra <- expand.grid(penalty = 1:3, mixture = (1:5)/5, blah = 10:12)
+  reg_grid_extra_smol <- min_grid(linear_reg() %>% set_engine("glmnet"), reg_grid_extra)
+
+  expect_equal(reg_grid_extra_smol$penalty, rep(3, 15))
+  expect_equal(reg_grid_extra_smol$mixture, rep((1:5)/5, each = 3))
+  expect_equal(reg_grid_extra_smol$blah, rep(10:12, 5))
+  for (i in 1:nrow(reg_grid_extra_smol)) {
+    expect_equal(reg_grid_extra_smol$.submodels[[i]], list(penalty = 1:2))
+  }
+
+})
+
