@@ -160,10 +160,9 @@ test_that('classification probabilities', {
       y = tr_dat$Class
     )
 
-  keras_pred <-
-    keras::predict_proba(lr_fit$fit, as.matrix(te_dat[, -1])) %>%
-    as_tibble() %>%
-    setNames(paste0(".pred_", lr_fit$lvl))
+  keras_pred <- keras::predict_proba(lr_fit$fit, as.matrix(te_dat[, -1]))
+  colnames(keras_pred) <- paste0(".pred_", lr_fit$lvl)
+  keras_pred <- as_tibble(keras_pred)
 
   parsnip_pred <- predict(lr_fit, te_dat[, -1], type = "prob")
   expect_equal(as.data.frame(keras_pred), as.data.frame(parsnip_pred))
@@ -177,10 +176,10 @@ test_that('classification probabilities', {
       y = tr_dat$Class
     )
 
-  keras_pred <-
-    keras::predict_proba(plrfit$fit, as.matrix(te_dat[, -1])) %>%
-    as_tibble() %>%
-    setNames(paste0(".pred_", lr_fit$lvl))
+  keras_pred <- keras::predict_proba(plrfit$fit, as.matrix(te_dat[, -1]))
+  colnames(keras_pred) <- paste0(".pred_", lr_fit$lvl)
+  keras_pred <- as_tibble(keras_pred)
+
   parsnip_pred <- predict(plrfit, te_dat[, -1], type = "prob")
   expect_equal(as.data.frame(keras_pred), as.data.frame(parsnip_pred))
 
