@@ -20,7 +20,7 @@ test_that('glmnet execution', {
   skip_if_not_installed("glmnet")
 
   expect_error(
-    fit_xy(
+    res <- fit_xy(
       multinom_reg() %>% set_engine("glmnet"),
       control = ctrl,
       x = iris[, 1:4],
@@ -29,6 +29,9 @@ test_that('glmnet execution', {
     regexp = NA
   )
 
+  expect_true(has_multi_predict(res))
+  expect_equal(multi_predict_args(res), "penalty")
+
   expect_error(
     glmnet_xy_catch <- fit_xy(
       multinom_reg() %>% set_engine("glmnet"),
@@ -58,7 +61,6 @@ test_that('glmnet prediction, one lambda', {
   uni_pred <- factor(uni_pred[,1], levels = levels(iris$Species))
   uni_pred <- unname(uni_pred)
 
-  expect_equal(uni_pred, parsnip:::predict_class.model_fit(xy_fit, iris[rows, 1:4]))
   expect_equal(uni_pred, predict(xy_fit, iris[rows, 1:4], type = "class")$.pred_class)
 
   res_form <- fit(
@@ -148,4 +150,38 @@ test_that('glmnet probabilities, mulitiple lambda', {
 
 })
 
+# ------------------------------------------------------------------------------
+
+test_that('glmnet grid reduction', {
+  reg_grid <- expand.grid(penalty = 1:3, mixture = (1:5)/5)
+  reg_grid_smol <- min_grid(multinom_reg() %>% set_engine("glmnet"), reg_grid)
+
+  expect_equal(reg_grid_smol$penalty, rep(3, 5))
+  expect_equal(reg_grid_smol$mixture, (1:5)/5)
+  for (i in 1:nrow(reg_grid_smol)) {
+    expect_equal(reg_grid_smol$.submodels[[i]], list(penalty = 1:2))
+  }
+
+  reg_ish_grid <- expand.grid(penalty = 1:3, mixture = (1:5)/5)[-3,]
+  reg_ish_grid_smol <- min_grid(multinom_reg() %>% set_engine("glmnet"), reg_ish_grid)
+
+  expect_equal(reg_ish_grid_smol$penalty, c(2, rep(3, 4)))
+  expect_equal(reg_ish_grid_smol$mixture, (1:5)/5)
+  expect_equal(reg_ish_grid_smol$.submodels[[1]], list(penalty = 1))
+  for (i in 2:nrow(reg_ish_grid_smol)) {
+    expect_equal(reg_ish_grid_smol$.submodels[[i]], list(penalty = 1:2))
+  }
+
+  reg_grid_extra <- expand.grid(penalty = 1:3, mixture = (1:5)/5, blah = 10:12)
+  reg_grid_extra_smol <- min_grid(multinom_reg() %>% set_engine("glmnet"), reg_grid_extra)
+
+  expect_equal(reg_grid_extra_smol$penalty, rep(3, 15))
+  expect_equal(reg_grid_extra_smol$mixture, rep((1:5)/5, each = 3))
+  expect_equal(reg_grid_extra_smol$blah, rep(10:12, 5))
+  for (i in 1:nrow(reg_grid_extra_smol)) {
+    expect_equal(reg_grid_extra_smol$.submodels[[i]], list(penalty = 1:2))
+  }
+
+})
+
 
