@@ -37,6 +37,9 @@ test_that('flexsurv execution', {
     ),
     regexp = NA
   )
+  expect_false(has_multi_predict(res))
+  expect_equal(multi_predict_args(res), NA_character_)
+
   expect_error(
     res <- fit_xy(
       surv_basic,
